==> openshift-model-5.8.1-sources.jar: io/fabric8/openshift/api/model/OAuthAccessTokenFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class OAuthAccessTokenFluentImpl<A extends io.fabric8.openshift.api.model.OAuthAccessTokenFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.OAuthAccessTokenFluent<A>{
  public OAuthAccessTokenFluentImpl() {
  }
  public OAuthAccessTokenFluentImpl(io.fabric8.openshift.api.model.OAuthAccessToken instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withAuthorizeToken(instance.getAuthorizeToken()); 
    this.withClientName(instance.getClientName()); 
    this.withExpiresIn(instance.getExpiresIn()); 
    this.withInactivityTimeoutSeconds(instance.getInactivityTimeoutSeconds()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withRedirectURI(instance.getRedirectURI()); 
    this.withRefreshToken(instance.getRefreshToken()); 
    this.withScopes(instance.getScopes()); 
    this.withUserName(instance.getUserName()); 
    this.withUserUID(instance.getUserUID()); 
  }
  private java.lang.String apiVersion;
  private java.lang.String authorizeToken;
  private java.lang.String clientName;
  private java.lang.Long expiresIn;
  private java.lang.Integer inactivityTimeoutSeconds;
  private java.lang.String kind;
  private io.fabric8.kubernetes.api.model.ObjectMetaBuilder metadata;
  private java.lang.String redirectURI;
  private java.lang.String refreshToken;
  private java.util.List<java.lang.String> scopes = new java.util.ArrayList<java.lang.String>();
  private java.lang.String userName;
  private java.lang.String userUID;
  public java.lang.String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(java.lang.String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public java.lang.Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0) {
    return (A)withApiVersion(new String(arg0));
  }
  public java.lang.String getAuthorizeToken() {
    return this.authorizeToken;
  }
  public A withAuthorizeToken(java.lang.String authorizeToken) {
    this.authorizeToken=authorizeToken; return (A) this;
  }
  public java.lang.Boolean hasAuthorizeToken() {
    return this.authorizeToken != null;
  }
  
  /**
   * Method is deprecated. use withAuthorizeToken instead.
   */
  @java.lang.Deprecated
  public A withNewAuthorizeToken(java.lang.String arg0) {
    return (A)withAuthorizeToken(new String(arg0));
  }
  public java.lang.String getClientName() {
    return this.clientName;
  }
  public A withClientName(java.lang.String clientName) {
    this.clientName=clientName; return (A) this;
  }
  public java.lang.Boolean hasClientName() {
    return this.clientName != null;
  }
  
  /**
   * Method is deprecated. use withClientName instead.
   */
  @java.lang.Deprecated
  public A withNewClientName(java.lang.String arg0) {
    return (A)withClientName(new String(arg0));
  }
  public java.lang.Long getExpiresIn() {
    return this.expiresIn;
  }
  public A withExpiresIn(java.lang.Long expiresIn) {
    this.expiresIn=expiresIn; return (A) this;
  }
  public java.lang.Boolean hasExpiresIn() {
    return this.expiresIn != null;
  }
  public java.lang.Integer getInactivityTimeoutSeconds() {
    return this.inactivityTimeoutSeconds;
  }
  public A withInactivityTimeoutSeconds(java.lang.Integer inactivityTimeoutSeconds) {
    this.inactivityTimeoutSeconds=inactivityTimeoutSeconds; return (A) this;
  }
  public java.lang.Boolean hasInactivityTimeoutSeconds() {
    return this.inactivityTimeoutSeconds != null;
  }
  public java.lang.String getKind() {
    return this.kind;
  }
  public A withKind(java.lang.String kind) {
    this.kind=kind; return (A) this;
  }
  public java.lang.Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0) {
    return (A)withKind(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectMeta getMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public io.fabric8.kubernetes.api.model.ObjectMeta buildMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public A withMetadata(io.fabric8.kubernetes.api.model.ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
  }
  public java.lang.Boolean hasMetadata() {
    return this.metadata != null;
  }
  public io.fabric8.openshift.api.model.OAuthAccessTokenFluent.MetadataNested<A> withNewMetadata() {
    return new io.fabric8.openshift.api.model.OAuthAccessTokenFluentImpl.MetadataNestedImpl();
  }
  public io.fabric8.openshift.api.model.OAuthAccessTokenFluent.MetadataNested<A> withNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item) {
    return new io.fabric8.openshift.api.model.OAuthAccessTokenFluentImpl.MetadataNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.OAuthAccessTokenFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public io.fabric8.openshift.api.model.OAuthAccessTokenFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new io.fabric8.kubernetes.api.model.ObjectMetaBuilder().build());
  }
  public io.fabric8.openshift.api.model.OAuthAccessTokenFluent.MetadataNested<A> editOrNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  public java.lang.String getRedirectURI() {
    return this.redirectURI;
  }
  public A withRedirectURI(java.lang.String redirectURI) {
    this.redirectURI=redirectURI; return (A) this;
  }
  public java.lang.Boolean hasRedirectURI() {
    return this.redirectURI != null;
  }
  
  /**
   * Method is deprecated. use withRedirectURI instead.
   */
  @java.lang.Deprecated
  public A withNewRedirectURI(java.lang.String arg0) {
    return (A)withRedirectURI(new String(arg0));
  }
  public java.lang.String getRefreshToken() {
    return this.refreshToken;
  }
  public A withRefreshToken(java.lang.String refreshToken) {
    this.refreshToken=refreshToken; return (A) this;
  }
  public java.lang.Boolean hasRefreshToken() {
    return this.refreshToken != null;
  }
  
  /**
   * Method is deprecated. use withRefreshToken instead.
   */
  @java.lang.Deprecated
  public A withNewRefreshToken(java.lang.String arg0) {
    return (A)withRefreshToken(new String(arg0));
  }
  public A addToScopes(java.lang.Integer index,java.lang.String item) {
    if (this.scopes == null) {this.scopes = new java.util.ArrayList<java.lang.String>();}
    this.scopes.add(index, item);
    return (A)this;
  }
  public A setToScopes(java.lang.Integer index,java.lang.String item) {
    if (this.scopes == null) {this.scopes = new java.util.ArrayList<java.lang.String>();}
    this.scopes.set(index, item); return (A)this;
  }
  public A addToScopes(java.lang.String... items) {
    if (this.scopes == null) {this.scopes = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.scopes.add(item);} return (A)this;
  }
  public A addAllToScopes(java.util.Collection<java.lang.String> items) {
    if (this.scopes == null) {this.scopes = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.scopes.add(item);} return (A)this;
  }
  public A removeFromScopes(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.scopes!= null){ this.scopes.remove(item);}} return (A)this;
  }
  public A removeAllFromScopes(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.scopes!= null){ this.scopes.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getScopes() {
    return this.scopes;
  }
  public java.lang.String getScope(java.lang.Integer index) {
    return this.scopes.get(index);
  }
  public java.lang.String getFirstScope() {
    return this.scopes.get(0);
  }
  public java.lang.String getLastScope() {
    return this.scopes.get(scopes.size() - 1);
  }
  public java.lang.String getMatchingScope(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: scopes) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingScope(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: scopes) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withScopes(java.util.List<java.lang.String> scopes) {
    if (scopes != null) {this.scopes = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : scopes){this.addToScopes(item);}} else { this.scopes = null;} return (A) this;
  }
  public A withScopes(java.lang.String... scopes) {
    if (this.scopes != null) {this.scopes.clear();}
    if (scopes != null) {for (java.lang.String item :scopes){ this.addToScopes(item);}} return (A) this;
  }
  public java.lang.Boolean hasScopes() {
    return scopes != null && !scopes.isEmpty();
  }
  public A addNewScope(java.lang.String arg0) {
    return (A)addToScopes(new String(arg0));
  }
  public java.lang.String getUserName() {
    return this.userName;
  }
  public A withUserName(java.lang.String userName) {
    this.userName=userName; return (A) this;
  }
  public java.lang.Boolean hasUserName() {
    return this.userName != null;
  }
  
  /**
   * Method is deprecated. use withUserName instead.
   */
  @java.lang.Deprecated
  public A withNewUserName(java.lang.String arg0) {
    return (A)withUserName(new String(arg0));
  }
  public java.lang.String getUserUID() {
    return this.userUID;
  }
  public A withUserUID(java.lang.String userUID) {
    this.userUID=userUID; return (A) this;
  }
  public java.lang.Boolean hasUserUID() {
    return this.userUID != null;
  }
  
  /**
   * Method is deprecated. use withUserUID instead.
   */
  @java.lang.Deprecated
  public A withNewUserUID(java.lang.String arg0) {
    return (A)withUserUID(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    OAuthAccessTokenFluentImpl that = (OAuthAccessTokenFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (authorizeToken != null ? !authorizeToken.equals(that.authorizeToken) :that.authorizeToken != null) return false;
    if (clientName != null ? !clientName.equals(that.clientName) :that.clientName != null) return false;
    if (expiresIn != null ? !expiresIn.equals(that.expiresIn) :that.expiresIn != null) return false;
    if (inactivityTimeoutSeconds != null ? !inactivityTimeoutSeconds.equals(that.inactivityTimeoutSeconds) :that.inactivityTimeoutSeconds != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (redirectURI != null ? !redirectURI.equals(that.redirectURI) :that.redirectURI != null) return false;
    if (refreshToken != null ? !refreshToken.equals(that.refreshToken) :that.refreshToken != null) return false;
    if (scopes != null ? !scopes.equals(that.scopes) :that.scopes != null) return false;
    if (userName != null ? !userName.equals(that.userName) :that.userName != null) return false;
    if (userUID != null ? !userUID.equals(that.userUID) :that.userUID != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  authorizeToken,  clientName,  expiresIn,  inactivityTimeoutSeconds,  kind,  metadata,  redirectURI,  refreshToken,  scopes,  userName,  userUID,  super.hashCode());
  }
  public class MetadataNestedImpl<N> extends io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl<io.fabric8.openshift.api.model.OAuthAccessTokenFluent.MetadataNested<N>> implements io.fabric8.openshift.api.model.OAuthAccessTokenFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MetadataNestedImpl(io.fabric8.kubernetes.api.model.ObjectMeta item) {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ObjectMetaBuilder builder;
    public N and() {
      return (N) OAuthAccessTokenFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/OAuthAccessTokenFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class OAuthAccessTokenFluentImpl<A extends io.fabric8.openshift.api.model.OAuthAccessTokenFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.OAuthAccessTokenFluent<A>{
  public OAuthAccessTokenFluentImpl() {
  }
  public OAuthAccessTokenFluentImpl(io.fabric8.openshift.api.model.OAuthAccessToken instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withAuthorizeToken(instance.getAuthorizeToken()); 
    this.withClientName(instance.getClientName()); 
    this.withExpiresIn(instance.getExpiresIn()); 
    this.withInactivityTimeoutSeconds(instance.getInactivityTimeoutSeconds()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withRedirectURI(instance.getRedirectURI()); 
    this.withRefreshToken(instance.getRefreshToken()); 
    this.withScopes(instance.getScopes()); 
    this.withUserName(instance.getUserName()); 
    this.withUserUID(instance.getUserUID()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String apiVersion;
  private java.lang.String authorizeToken;
  private java.lang.String clientName;
  private java.lang.Long expiresIn;
  private java.lang.Integer inactivityTimeoutSeconds;
  private java.lang.String kind;
  private io.fabric8.kubernetes.api.model.ObjectMetaBuilder metadata;
  private java.lang.String redirectURI;
  private java.lang.String refreshToken;
  private java.util.List<java.lang.String> scopes = new java.util.ArrayList<java.lang.String>();
  private java.lang.String userName;
  private java.lang.String userUID;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(java.lang.String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public java.lang.Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0) {
    return (A)withApiVersion(new String(arg0));
  }
  public java.lang.String getAuthorizeToken() {
    return this.authorizeToken;
  }
  public A withAuthorizeToken(java.lang.String authorizeToken) {
    this.authorizeToken=authorizeToken; return (A) this;
  }
  public java.lang.Boolean hasAuthorizeToken() {
    return this.authorizeToken != null;
  }
  
  /**
   * Method is deprecated. use withAuthorizeToken instead.
   */
  @java.lang.Deprecated
  public A withNewAuthorizeToken(java.lang.String arg0) {
    return (A)withAuthorizeToken(new String(arg0));
  }
  public java.lang.String getClientName() {
    return this.clientName;
  }
  public A withClientName(java.lang.String clientName) {
    this.clientName=clientName; return (A) this;
  }
  public java.lang.Boolean hasClientName() {
    return this.clientName != null;
  }
  
  /**
   * Method is deprecated. use withClientName instead.
   */
  @java.lang.Deprecated
  public A withNewClientName(java.lang.String arg0) {
    return (A)withClientName(new String(arg0));
  }
  public java.lang.Long getExpiresIn() {
    return this.expiresIn;
  }
  public A withExpiresIn(java.lang.Long expiresIn) {
    this.expiresIn=expiresIn; return (A) this;
  }
  public java.lang.Boolean hasExpiresIn() {
    return this.expiresIn != null;
  }
  public java.lang.Integer getInactivityTimeoutSeconds() {
    return this.inactivityTimeoutSeconds;
  }
  public A withInactivityTimeoutSeconds(java.lang.Integer inactivityTimeoutSeconds) {
    this.inactivityTimeoutSeconds=inactivityTimeoutSeconds; return (A) this;
  }
  public java.lang.Boolean hasInactivityTimeoutSeconds() {
    return this.inactivityTimeoutSeconds != null;
  }
  public java.lang.String getKind() {
    return this.kind;
  }
  public A withKind(java.lang.String kind) {
    this.kind=kind; return (A) this;
  }
  public java.lang.Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0) {
    return (A)withKind(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectMeta getMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public io.fabric8.kubernetes.api.model.ObjectMeta buildMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public A withMetadata(io.fabric8.kubernetes.api.model.ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
  }
  public java.lang.Boolean hasMetadata() {
    return this.metadata != null;
  }
  public io.fabric8.openshift.api.model.OAuthAccessTokenFluent.MetadataNested<A> withNewMetadata() {
    return new io.fabric8.openshift.api.model.OAuthAccessTokenFluentImpl.MetadataNestedImpl();
  }
  public io.fabric8.openshift.api.model.OAuthAccessTokenFluent.MetadataNested<A> withNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item) {
    return new io.fabric8.openshift.api.model.OAuthAccessTokenFluentImpl.MetadataNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.OAuthAccessTokenFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public io.fabric8.openshift.api.model.OAuthAccessTokenFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new io.fabric8.kubernetes.api.model.ObjectMetaBuilder().build());
  }
  public io.fabric8.openshift.api.model.OAuthAccessTokenFluent.MetadataNested<A> editOrNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  public java.lang.String getRedirectURI() {
    return this.redirectURI;
  }
  public A withRedirectURI(java.lang.String redirectURI) {
    this.redirectURI=redirectURI; return (A) this;
  }
  public java.lang.Boolean hasRedirectURI() {
    return this.redirectURI != null;
  }
  
  /**
   * Method is deprecated. use withRedirectURI instead.
   */
  @java.lang.Deprecated
  public A withNewRedirectURI(java.lang.String arg0) {
    return (A)withRedirectURI(new String(arg0));
  }
  public java.lang.String getRefreshToken() {
    return this.refreshToken;
  }
  public A withRefreshToken(java.lang.String refreshToken) {
    this.refreshToken=refreshToken; return (A) this;
  }
  public java.lang.Boolean hasRefreshToken() {
    return this.refreshToken != null;
  }
  
  /**
   * Method is deprecated. use withRefreshToken instead.
   */
  @java.lang.Deprecated
  public A withNewRefreshToken(java.lang.String arg0) {
    return (A)withRefreshToken(new String(arg0));
  }
  public A addToScopes(java.lang.Integer index,java.lang.String item) {
    if (this.scopes == null) {this.scopes = new java.util.ArrayList<java.lang.String>();}
    this.scopes.add(index, item);
    return (A)this;
  }
  public A setToScopes(java.lang.Integer index,java.lang.String item) {
    if (this.scopes == null) {this.scopes = new java.util.ArrayList<java.lang.String>();}
    this.scopes.set(index, item); return (A)this;
  }
  public A addToScopes(java.lang.String... items) {
    if (this.scopes == null) {this.scopes = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.scopes.add(item);} return (A)this;
  }
  public A addAllToScopes(java.util.Collection<java.lang.String> items) {
    if (this.scopes == null) {this.scopes = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.scopes.add(item);} return (A)this;
  }
  public A removeFromScopes(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.scopes!= null){ this.scopes.remove(item);}} return (A)this;
  }
  public A removeAllFromScopes(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.scopes!= null){ this.scopes.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getScopes() {
    return this.scopes;
  }
  public java.lang.String getScope(java.lang.Integer index) {
    return this.scopes.get(index);
  }
  public java.lang.String getFirstScope() {
    return this.scopes.get(0);
  }
  public java.lang.String getLastScope() {
    return this.scopes.get(scopes.size() - 1);
  }
  public java.lang.String getMatchingScope(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: scopes) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingScope(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: scopes) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withScopes(java.util.List<java.lang.String> scopes) {
    if (scopes != null) {this.scopes = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : scopes){this.addToScopes(item);}} else { this.scopes = null;} return (A) this;
  }
  public A withScopes(java.lang.String... scopes) {
    if (this.scopes != null) {this.scopes.clear();}
    if (scopes != null) {for (java.lang.String item :scopes){ this.addToScopes(item);}} return (A) this;
  }
  public java.lang.Boolean hasScopes() {
    return scopes != null && !scopes.isEmpty();
  }
  public A addNewScope(java.lang.String arg0) {
    return (A)addToScopes(new String(arg0));
  }
  public java.lang.String getUserName() {
    return this.userName;
  }
  public A withUserName(java.lang.String userName) {
    this.userName=userName; return (A) this;
  }
  public java.lang.Boolean hasUserName() {
    return this.userName != null;
  }
  
  /**
   * Method is deprecated. use withUserName instead.
   */
  @java.lang.Deprecated
  public A withNewUserName(java.lang.String arg0) {
    return (A)withUserName(new String(arg0));
  }
  public java.lang.String getUserUID() {
    return this.userUID;
  }
  public A withUserUID(java.lang.String userUID) {
    this.userUID=userUID; return (A) this;
  }
  public java.lang.Boolean hasUserUID() {
    return this.userUID != null;
  }
  
  /**
   * Method is deprecated. use withUserUID instead.
   */
  @java.lang.Deprecated
  public A withNewUserUID(java.lang.String arg0) {
    return (A)withUserUID(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    OAuthAccessTokenFluentImpl that = (OAuthAccessTokenFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (authorizeToken != null ? !authorizeToken.equals(that.authorizeToken) :that.authorizeToken != null) return false;
    if (clientName != null ? !clientName.equals(that.clientName) :that.clientName != null) return false;
    if (expiresIn != null ? !expiresIn.equals(that.expiresIn) :that.expiresIn != null) return false;
    if (inactivityTimeoutSeconds != null ? !inactivityTimeoutSeconds.equals(that.inactivityTimeoutSeconds) :that.inactivityTimeoutSeconds != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (redirectURI != null ? !redirectURI.equals(that.redirectURI) :that.redirectURI != null) return false;
    if (refreshToken != null ? !refreshToken.equals(that.refreshToken) :that.refreshToken != null) return false;
    if (scopes != null ? !scopes.equals(that.scopes) :that.scopes != null) return false;
    if (userName != null ? !userName.equals(that.userName) :that.userName != null) return false;
    if (userUID != null ? !userUID.equals(that.userUID) :that.userUID != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  authorizeToken,  clientName,  expiresIn,  inactivityTimeoutSeconds,  kind,  metadata,  redirectURI,  refreshToken,  scopes,  userName,  userUID,  additionalProperties,  super.hashCode());
  }
  public class MetadataNestedImpl<N> extends io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl<io.fabric8.openshift.api.model.OAuthAccessTokenFluent.MetadataNested<N>> implements io.fabric8.openshift.api.model.OAuthAccessTokenFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MetadataNestedImpl(io.fabric8.kubernetes.api.model.ObjectMeta item) {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ObjectMetaBuilder builder;
    public N and() {
      return (N) OAuthAccessTokenFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  
}
